
/* this file produces Figures 3 to 8 of the paper Basso-Peri 2015 */

clear all
set scheme s1mono
set more off
cap log close

cd C:\Users\Tano\Dropbox\Giovanni_MigrationConference2015\Basso_Peri_Chapter_1\

log using output\logs\Figure_3_8.txt, text replace

disp "DateTime: $S_DATE $S_TIME"

/* *******************************************************************
 Scatter plots with CZ-aggregated dataset (wages and employment of 
 natives vs. immigrant change as share of the population)
 
 Created on 1/7/2015 by Gaetano Basso (gbasso@ucdavis.edu)
 Revised on 9/16/2015 by Gaetano Basso
******************************************************************* */

use data/aggregated_czone.dta, clear


*** Figure 3, 5, 7 and 8: Changes in natives logwages, empl, wages low-skill and high-skill vs. changes immig share, pooled 1970-2010 ***
graph drop _all

* Create de-meaned variables wages and employment
foreach v in lweekly nnative lweekly_lskill lweekly_hskill {
	local var: variable label `v'

	bys survey: egen d`v'_decadeavg=mean(d`v')
	gen d`v'_resid=d`v'-d`v'_decadeavg
}
bys survey: egen d_immi_std_decadeavg=mean(d_immi_std)
gen d_immi_std_resid=d_immi_std-d_immi_std_decadeavg

* Scatteplot for wages and employment (and regression to print beta/s.e. on graph)
foreach v in lweekly nnative lweekly_lskill lweekly_hskill {

	* Regressions
	xtset
	reg d`v' d_immi_std i.decade [aw=l.population], vce(cluster czone)
	local b`v': di _b[d_immi_std]
	local se`v': di %9.3f _se[d_immi_std]

	* Location of the betas and se on graphs
	if "`v'"=="nnative" {
		local b_xpos = .3
		local b_ypos = 2
		local se_xpos = .3
		local se_ypos = 1.75
	}
	else {
		local b_xpos = .3
		local b_ypos = .4
		local se_xpos = .3
		local se_ypos = .35
	}
	
	* Scatterplots
	xtset
	twoway scatter d`v'_resid d_immi_std_resid [w=l.population], msymbol(circle_hollow) || ///
	lfit d`v'_resid d_immi_std_resid [aw=l.population], ///
	saving("output/graphs/scatter_d_`v'_immistd_pooled", replace) ///
	name("scatter_d_`v'_pooled", replace) legend(off) ///
	title("") ylabel(,angle(0)) xtitle("") ytitle("") ///
	graphregion(margin(l-5 r+5)) ///
	text(`b_ypos' `b_xpos' "{&beta}=`=string(`b`v'',"%9.3f")'", placement(right)) ///
	text(`se_ypos' `se_xpos' "s.e.=`=string(`se`v'',"%9.3f")'", placement(right))  
	
	graph export output/graphs/scatter_d_`v'_immistd_pooled.png, replace
}	



*** Figure 4 and 6: Changes logwages and employment vs. changes immig share, by decade ***
graph drop _all

foreach v in lweekly nnative {
	local var: variable label `v'

	forvalues y=2/5 {

		local dec: label decadename `y'

		* Regressions
		reg d`v' d_immi_std [aw=l.population] if decade==`y', vce(cluster czone)
		local b`v': di _b[d_immi_std]
		local se`v': di %9.3f _se[d_immi_std]
				
			* Location of the betas and se on graphs
		if "`v'"=="nnative" {
			local b_xpos = .3
			local b_ypos = 2
			local se_xpos = .3
			local se_ypos = 1.75
		}
		else {
			local b_xpos = .3
			local b_ypos = .4
			local se_xpos = .3
			local se_ypos = .35
		}
		twoway scatter d`v' d_immi_std [w=l.population] if decade==`y', ///
		msymbol(circle_hollow) || ///
		lfit d`v' d_immi_std [aw=l.population] if decade==`y' , ///
		saving("output/graphs/scatter_d_`v'_immistd_`y'", replace) ///
		name("scatter_d_`v'_immistd_`y'", replace) legend(off) ///
		title("`dec'") ylabel(,angle(0)) xtitle("") ytitle("") ///
		graphregion(margin(l-10 r+1)) ///
		text(`b_ypos' `b_xpos' "{&beta}=`=string(`b`v'',"%9.3f")'", placement(right)) ///
		text(`se_ypos' `se_xpos' "s.e.=`=string(`se`v'',"%9.3f")'", placement(right)) 		

	}	
	graph combine "output/graphs/scatter_d_`v'_immistd_2" ///
		"output/graphs/scatter_d_`v'_immistd_3" ///
		 "output/graphs/scatter_d_`v'_immistd_4" ///
		 "output/graphs/scatter_d_`v'_immistd_5", ///
		 saving(output/graphs/scatter_d_`v'_d_immi_std, replace) /// 
		 title("") name(scatter_d_`v', replace) ycommon xcommon
	graph export output/graphs/scatter_d_`v'_immistd_bydecade.png, replace
}


*** Clean folder ***
cd output/graphs
shell erase *.gph

log close
